==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PArrayDescriptor.h <==
// public final class soot.jimple.parser.node.X2PArrayDescriptor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 53655e27b2411791 soot_jimple_parser_node_X2PArrayDescriptor
// @dep_class fd867b42f5c66a2 soot_jimple_parser_node_XPArrayDescriptor

// header file dependencies
// @dep_header soot_jimple_parser_node_XPArrayDescriptor

#include "soot/jimple/parser/node/XPArrayDescriptor.h"

#ifndef _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_
#define _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayDescriptor$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$refs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object	_jc_soot_jimple_parser_node_X2PArrayDescriptor$object;

typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$_init$faf7ca543afc4877(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
extern struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$getPArrayDescriptor$57d960fed49f6a4e(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$setPArrayDescriptor$8c25fa1b742a9483(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$getPArrayDescriptor$57d960fed49f6a4e;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$setPArrayDescriptor$8c25fa1b742a9483;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
	struct _jc_soot_jimple_parser_node_PArrayDescriptor$object	*(*getPArrayDescriptor$57d960fed49f6a4e)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPArrayDescriptor$8c25fa1b742a9483)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPArrayDescriptor$vmethods	soot_jimple_parser_node_XPArrayDescriptor;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods	soot_jimple_parser_node_X2PArrayDescriptor;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayDescriptor$object	*__5fpArrayDescriptor__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$refs {
    _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs	soot_jimple_parser_node_X2PArrayDescriptor;
    _jc_soot_jimple_parser_node_XPArrayDescriptor$sub_refs	soot_jimple_parser_node_XPArrayDescriptor;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPArrayDescriptor$sub_nonrefs	soot_jimple_parser_node_XPArrayDescriptor;
    _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs	soot_jimple_parser_node_X2PArrayDescriptor;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object {
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype _jc_soot_jimple_parser_node_X2PArrayDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PArrayDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PArrayDescriptor$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PArrayDescriptor.h <==
// public final class soot.jimple.parser.node.X2PArrayDescriptor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 53655e27b2411791 soot_jimple_parser_node_X2PArrayDescriptor
// @dep_class fd867b42f5c66a2 soot_jimple_parser_node_XPArrayDescriptor

// header file dependencies
// @dep_header soot_jimple_parser_node_XPArrayDescriptor

#include "soot/jimple/parser/node/XPArrayDescriptor.h"

#ifndef _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_
#define _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PArrayDescriptor$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$refs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$refs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs	_jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object	_jc_soot_jimple_parser_node_X2PArrayDescriptor$object;

typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$_init$faf7ca543afc4877(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$getPArrayDescriptor$57d960fed49f6a4e(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PArrayDescriptor$method$setPArrayDescriptor$8c25fa1b742a9483(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PArrayDescriptor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$getPArrayDescriptor$57d960fed49f6a4e;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$setPArrayDescriptor$8c25fa1b742a9483;
extern _jc_method _jc_soot_jimple_parser_node_X2PArrayDescriptor$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PArrayDescriptor$object	*(*getPArrayDescriptor$57d960fed49f6a4e)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPArrayDescriptor$8c25fa1b742a9483)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *, struct _jc_soot_jimple_parser_node_PArrayDescriptor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPArrayDescriptor$vmethods	soot_jimple_parser_node_XPArrayDescriptor;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vmethods	soot_jimple_parser_node_X2PArrayDescriptor;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs {
	struct _jc_soot_jimple_parser_node_PArrayDescriptor$object	*__5fpArrayDescriptor__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$refs {
    _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_refs	soot_jimple_parser_node_X2PArrayDescriptor;
    _jc_soot_jimple_parser_node_XPArrayDescriptor$sub_refs	soot_jimple_parser_node_XPArrayDescriptor;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPArrayDescriptor$sub_nonrefs	soot_jimple_parser_node_XPArrayDescriptor;
    _jc_soot_jimple_parser_node_X2PArrayDescriptor$sub_nonrefs	soot_jimple_parser_node_X2PArrayDescriptor;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PArrayDescriptor$object {
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PArrayDescriptor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PArrayDescriptor$vtype _jc_soot_jimple_parser_node_X2PArrayDescriptor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PArrayDescriptor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PArrayDescriptor$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PArrayDescriptor_H_ */
